@@ -3,7 +3,7 @@ from typing import Any, Dict, List, Optional, Union, cast
 
 import httpx
 
-from legaltech_api_client.client import Client
+from legaltech_api_client.client import AuthenticatedClient
 from legaltech_api_client.models.activity import Activity
 from legaltech_api_client.types import UNSET, Response, Unset
 
@@ -11,21 +11,18 @@ from legaltech_api_client.types import UNSET, Response, Unset
 def _get_kwargs(
     claim_id: str,
     *,
-    client: Client,
+    client: AuthenticatedClient,
     created_at: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_gt: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_gte: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_lt: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_lte: Union[Unset, None, datetime.datetime] = UNSET,
-    authorization: str,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/claims/{claim_id}/activities/".format(client.base_url, claim_id=claim_id)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    headers["Authorization"] = authorization
-
     params: Dict[str, Any] = {}
     json_created_at: Union[Unset, None, str] = UNSET
     if not isinstance(created_at, Unset):
@@ -103,25 +100,23 @@ def _build_response(*, response: httpx.Response) -> Response[Union[Any, List[Act
 def sync_detailed(
     claim_id: str,
     *,
-    client: Client,
+    client: AuthenticatedClient,
     created_at: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_gt: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_gte: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_lt: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_lte: Union[Unset, None, datetime.datetime] = UNSET,
-    authorization: str,
 ) -> Response[Union[Any, List[Activity]]]:
     """Get activities perform on a Claim.
 
     Args:
         claim_id (str):
-        client (Client):
+        client (AuthenticatedClient):
         created_at (Union[Unset, None, datetime.datetime]):
         created_at_gt (Union[Unset, None, datetime.datetime]):
         created_at_gte (Union[Unset, None, datetime.datetime]):
         created_at_lt (Union[Unset, None, datetime.datetime]):
         created_at_lte (Union[Unset, None, datetime.datetime]):
-        authorization (str):
 
     Returns:
         Response[Union[Any, List[Activity]]]
@@ -135,7 +130,6 @@ def sync_detailed(
         created_at_gte=created_at_gte,
         created_at_lt=created_at_lt,
         created_at_lte=created_at_lte,
-        authorization=authorization,
     )
 
     response = httpx.request(
@@ -149,25 +143,23 @@ def sync_detailed(
 def sync(
     claim_id: str,
     *,
-    client: Client,
+    client: AuthenticatedClient,
     created_at: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_gt: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_gte: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_lt: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_lte: Union[Unset, None, datetime.datetime] = UNSET,
-    authorization: str,
 ) -> Optional[Union[Any, List[Activity]]]:
     """Get activities perform on a Claim.
 
     Args:
         claim_id (str):
-        client (Client):
+        client (AuthenticatedClient):
         created_at (Union[Unset, None, datetime.datetime]):
         created_at_gt (Union[Unset, None, datetime.datetime]):
         created_at_gte (Union[Unset, None, datetime.datetime]):
         created_at_lt (Union[Unset, None, datetime.datetime]):
         created_at_lte (Union[Unset, None, datetime.datetime]):
-        authorization (str):
 
     Returns:
         Response[Union[Any, List[Activity]]]
@@ -181,32 +173,29 @@ def sync(
         created_at_gte=created_at_gte,
         created_at_lt=created_at_lt,
         created_at_lte=created_at_lte,
-        authorization=authorization,
     ).parsed
 
 
 async def asyncio_detailed(
     claim_id: str,
     *,
-    client: Client,
+    client: AuthenticatedClient,
     created_at: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_gt: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_gte: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_lt: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_lte: Union[Unset, None, datetime.datetime] = UNSET,
-    authorization: str,
 ) -> Response[Union[Any, List[Activity]]]:
     """Get activities perform on a Claim.
 
     Args:
         claim_id (str):
-        client (Client):
+        client (AuthenticatedClient):
         created_at (Union[Unset, None, datetime.datetime]):
         created_at_gt (Union[Unset, None, datetime.datetime]):
         created_at_gte (Union[Unset, None, datetime.datetime]):
         created_at_lt (Union[Unset, None, datetime.datetime]):
         created_at_lte (Union[Unset, None, datetime.datetime]):
-        authorization (str):
 
     Returns:
         Response[Union[Any, List[Activity]]]
@@ -220,7 +209,6 @@ async def asyncio_detailed(
         created_at_gte=created_at_gte,
         created_at_lt=created_at_lt,
         created_at_lte=created_at_lte,
-        authorization=authorization,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
@@ -232,13 +220,12 @@ async def asyncio_detailed(
 async def asyncio(
     claim_id: str,
     *,
-    client: Client,
+    client: AuthenticatedClient,
     created_at: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_gt: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_gte: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_lt: Union[Unset, None, datetime.datetime] = UNSET,
     created_at_lte: Union[Unset, None, datetime.datetime] = UNSET,
-    authorization: str,
 ) -> Optional[Union[Any, List[Activity]]]:
     """Get activities perform on a Claim.
 
@@ -250,7 +237,6 @@ async def asyncio(
         created_at_gte (Union[Unset, None, datetime.datetime]):
         created_at_lt (Union[Unset, None, datetime.datetime]):
         created_at_lte (Union[Unset, None, datetime.datetime]):
-        authorization (str):
 
     Returns:
         Response[Union[Any, List[Activity]]]
@@ -265,6 +251,5 @@ async def asyncio(
             created_at_gte=created_at_gte,
             created_at_lt=created_at_lt,
             created_at_lte=created_at_lte,
-            authorization=authorization,
         )
     ).parsed
