@@ -2,7 +2,7 @@ from typing import Any, Dict, Optional, Union, cast
 
 import httpx
 
-from legaltech_api_client.client import Client
+from legaltech_api_client.client import AuthenticatedClient
 from legaltech_api_client.models.claim_retrieve import ClaimRetrieve
 from legaltech_api_client.types import Response
 
@@ -10,16 +10,13 @@ from legaltech_api_client.types import Response
 def _get_kwargs(
     claim_id: str,
     *,
-    client: Client,
-    authorization: str,
+    client: AuthenticatedClient,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/claims/{claim_id}/".format(client.base_url, claim_id=claim_id)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    headers["Authorization"] = authorization
-
     return {
         "method": "get",
         "url": url,
@@ -55,15 +52,13 @@ def _build_response(*, response: httpx.Response) -> Response[Union[Any, ClaimRet
 def sync_detailed(
     claim_id: str,
     *,
-    client: Client,
-    authorization: str,
+    client: AuthenticatedClient,
 ) -> Response[Union[Any, ClaimRetrieve]]:
     """Get Claim details by ID
 
     Args:
         claim_id (str):
-        client (Client):
-        authorization (str):
+        client (AuthenticatedClient):
 
     Returns:
         Response[Union[Any, ClaimRetrieve]]
@@ -72,7 +67,6 @@ def sync_detailed(
     kwargs = _get_kwargs(
         claim_id=claim_id,
         client=client,
-        authorization=authorization,
     )
 
     response = httpx.request(
@@ -86,15 +80,13 @@ def sync_detailed(
 def sync(
     claim_id: str,
     *,
-    client: Client,
-    authorization: str,
+    client: AuthenticatedClient,
 ) -> Optional[Union[Any, ClaimRetrieve]]:
     """Get Claim details by ID
 
     Args:
         claim_id (str):
-        client (Client):
-        authorization (str):
+        client (AuthenticatedClient):
 
     Returns:
         Response[Union[Any, ClaimRetrieve]]
@@ -103,22 +95,19 @@ def sync(
     return sync_detailed(
         claim_id=claim_id,
         client=client,
-        authorization=authorization,
     ).parsed
 
 
 async def asyncio_detailed(
     claim_id: str,
     *,
-    client: Client,
-    authorization: str,
+    client: AuthenticatedClient,
 ) -> Response[Union[Any, ClaimRetrieve]]:
     """Get Claim details by ID
 
     Args:
         claim_id (str):
         client (Client):
-        authorization (str):
 
     Returns:
         Response[Union[Any, ClaimRetrieve]]
@@ -127,7 +116,6 @@ async def asyncio_detailed(
     kwargs = _get_kwargs(
         claim_id=claim_id,
         client=client,
-        authorization=authorization,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
@@ -139,15 +127,13 @@ async def asyncio_detailed(
 async def asyncio(
     claim_id: str,
     *,
-    client: Client,
-    authorization: str,
+    client: AuthenticatedClient,
 ) -> Optional[Union[Any, ClaimRetrieve]]:
     """Get Claim details by ID
 
     Args:
         claim_id (str):
-        client (Client):
-        authorization (str):
+        client (AuthenticatedClient):
 
     Returns:
         Response[Union[Any, ClaimRetrieve]]
@@ -157,6 +143,5 @@ async def asyncio(
         await asyncio_detailed(
             claim_id=claim_id,
             client=client,
-            authorization=authorization,
         )
     ).parsed
