@@ -2,14 +2,14 @@ from typing import Any, Dict, List, Optional
 
 import httpx
 
-from legaltech_api_client.client import Client
+from legaltech_api_client.client import AuthenticatedClient
 from legaltech_api_client.models.service import Service
 from legaltech_api_client.types import Response
 
 
 def _get_kwargs(
     *,
-    client: Client,
+    client: AuthenticatedClient,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/services/".format(client.base_url)
 
@@ -49,11 +49,11 @@ def _build_response(*, response: httpx.Response) -> Response[List[Service]]:
 
 def sync_detailed(
     *,
-    client: Client,
+    client: AuthenticatedClient,
 ) -> Response[List[Service]]:
     """
     Args:
-        client (Client):
+        client (AuthenticatedClient):
 
     Returns:
         Response[List[Service]]
@@ -73,7 +73,7 @@ def sync_detailed(
 
 def sync(
     *,
-    client: Client,
+    client: AuthenticatedClient,
 ) -> Optional[List[Service]]:
     """
     Args:
@@ -90,11 +90,11 @@ def sync(
 
 async def asyncio_detailed(
     *,
-    client: Client,
+    client: AuthenticatedClient,
 ) -> Response[List[Service]]:
     """
     Args:
-        client (Client):
+        client (AuthenticatedClient):
 
     Returns:
         Response[List[Service]]
@@ -112,11 +112,11 @@ async def asyncio_detailed(
 
 async def asyncio(
     *,
-    client: Client,
+    client: AuthenticatedClient,
 ) -> Optional[List[Service]]:
     """
     Args:
-        client (Client):
+        client (AuthenticatedClient):
 
     Returns:
         Response[List[Service]]
